@@ -576,9 +576,10 @@ ea_day_view_main_item_get_cell_data (EaDayViewMainItem *ea_main_item)
 		cell_data = ea_cell_table_create (
 			day_view->rows,
 			e_day_view_get_days_shown (day_view), TRUE);
-		g_object_set_data (
+		g_object_set_data_full (
 			G_OBJECT (ea_main_item),
-			"ea-day-view-cell-table", cell_data);
+			"ea-day-view-cell-table", cell_data,
+			(GDestroyNotify) ea_cell_table_destroy);
 	}
 	return cell_data;
 }
@@ -586,19 +587,11 @@ ea_day_view_main_item_get_cell_data (EaDayViewMainItem *ea_main_item)
 static void
 ea_day_view_main_item_destory_cell_data (EaDayViewMainItem *ea_main_item)
 {
-	EaCellTable *cell_data;
-
 	g_return_if_fail (ea_main_item);
 
-	cell_data = g_object_get_data (
+	g_object_set_data (
 		G_OBJECT (ea_main_item),
-		"ea-day-view-cell-table");
-	if (cell_data) {
-		g_object_set_data (
-			G_OBJECT (ea_main_item),
-			"ea-day-view-cell-table", NULL);
-		ea_cell_table_destroy (cell_data);
-	}
+		"ea-day-view-cell-table", NULL);
 }
 
 /* Atk Component Interface */
