@@ -1758,6 +1758,12 @@ forward_non_attached (EMailBackend *backend,
 	shell = e_shell_backend_get_shell (E_SHELL_BACKEND (backend));
 
 	forward = quoting_text (QUOTING_FORWARD);
+	if (style == E_MAIL_FORWARD_STYLE_INLINE && forward) {
+		gchar *tmp = forward;
+		forward = g_strconcat (forward, "<br>", NULL);
+		g_free (tmp);
+	}
+
 	text = em_utils_message_to_html (
 		CAMEL_SESSION (session), message,
 		forward, flags, NULL, NULL, &validity_found);
@@ -2118,7 +2124,7 @@ reply_get_composer (EShell *shell,
 	if ((subject = (gchar *) camel_mime_message_get_subject (message))) {
 		gboolean skip_len = -1;
 
-		if (em_utils_is_re_in_subject (subject, &skip_len) && skip_len > 0)
+		if (em_utils_is_re_in_subject (subject, &skip_len, NULL) && skip_len > 0)
 			subject = subject + skip_len;
 
 		subject = g_strdup_printf ("Re: %s", subject);
