@@ -52,8 +52,7 @@ settings_spell_entry_constructed (GObject *object)
 	g_object_unref (settings);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_settings_spell_entry_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_settings_spell_entry_parent_class)->constructed (object);
 }
 
 static void
